@@ -1,12 +1,12 @@
 package File::Dir::Dumper;
-$File::Dir::Dumper::VERSION = 'v0.4.0';
+$File::Dir::Dumper::VERSION = '0.6.0';
 use warnings;
 use strict;
 
 use 5.012;
 
 
-1; # End of File::Dir::Dumper
+1;    # End of File::Dir::Dumper
 
 __END__
 
@@ -21,7 +21,7 @@ machine-readable way.
 
 =head1 VERSION
 
-version v0.4.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -34,10 +34,6 @@ version v0.4.0
         }
     );
 
-=head1 VERSION
-
-version v0.4.0
-
 =head1 METHODS
 
 =head1 AUTHOR
@@ -94,37 +90,10 @@ Copyright 2008 Shlomi Fish, all rights reserved.
 
 This program is released under the following license: MIT/X11 Licence.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2008 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/file-dir-dumper/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Dir::Dumper
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -138,15 +107,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/File-Dir-Dumper>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Dir-Dumper>
+L<https://metacpan.org/release/File-Dir-Dumper>
 
 =item *
 
@@ -158,30 +119,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Dir-Dumper>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Dir-Dumper>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Dir-Dumper>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/File-Dir-Dumper>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -192,7 +129,7 @@ L<http://cpants.cpanauthors.org/dist/File-Dir-Dumper>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/F/File-Dir-Dumper>
 
@@ -230,4 +167,25 @@ L<https://github.com/shlomif/perl-File-Dir-Dumper>
 
   git clone https://github.com/shlomif/perl-File-Dir-Dumper
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/file-dir-dumper/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
