@@ -1,5 +1,5 @@
 package File::Dir::Dumper::App;
-$File::Dir::Dumper::App::VERSION = 'v0.4.0';
+$File::Dir::Dumper::App::VERSION = '0.6.0';
 use warnings;
 use strict;
 
@@ -7,23 +7,20 @@ use 5.012;
 
 use parent 'File::Dir::Dumper::Base';
 
-use Carp;
-
 use Getopt::Long qw(GetOptionsFromArray);
-use Pod::Usage;
+use Pod::Usage qw( pod2usage );
 
-use File::Dir::Dumper::Scanner;
-use File::Dir::Dumper::Stream::JSON::Writer;
+use File::Dir::Dumper::Scanner              ();
+use File::Dir::Dumper::Stream::JSON::Writer ();
 
-use Class::XSAccessor
-    accessors => {
-        _digest_cache => '_digest_cache',
-        _digest_cache_params => '_digest_cache_params',
-        _digests => '_digests',
-        _out_to_stdout => '_out_to_stdout',
-        _out_filename => '_out_filename',
-        _dir_to_dump => '_dir_to_dump',
-    };
+use Class::XSAccessor accessors => {
+    _digest_cache        => '_digest_cache',
+    _digest_cache_params => '_digest_cache_params',
+    _digests             => '_digests',
+    _out_to_stdout       => '_out_to_stdout',
+    _out_filename        => '_out_filename',
+    _dir_to_dump         => '_dir_to_dump',
+};
 
 
 sub _init
@@ -35,25 +32,26 @@ sub _init
 
     my $output_dest;
     my @digests;
-    my ($help, $man);
+    my ( $help, $man );
     my $digest_cache = 'Dummy';
     my %cache_params;
 
-    GetOptionsFromArray($argv,
-        'digest-cache=s' => \$digest_cache,
+    GetOptionsFromArray(
+        $argv,
+        'digest-cache=s'       => \$digest_cache,
         'digest-cache-param=s' => \%cache_params,
-        "digest=s" => \@digests,
-        "output|o=s" => \$output_dest,
-        'help|h' => \$help,
-        'man' => \$man,
+        "digest=s"             => \@digests,
+        "output|o=s"           => \$output_dest,
+        'help|h'               => \$help,
+        'man'                  => \$man,
     ) or die "parsing options failed - $!";
 
-    pod2usage(1) if $help;
-    pod2usage(-exitstatus => 0, -verbose => 2) if $man;
+    pod2usage(1)                                 if $help;
+    pod2usage( -exitstatus => 0, -verbose => 2 ) if $man;
 
     my $dir_to_dump = shift(@$argv);
 
-    if (defined($output_dest))
+    if ( defined($output_dest) )
     {
         $self->_out_to_stdout(0);
         $self->_out_filename($output_dest);
@@ -62,10 +60,10 @@ sub _init
     {
         $self->_out_to_stdout(1);
     }
-    $self->_digests(\@digests);
+    $self->_digests( \@digests );
     $self->_dir_to_dump($dir_to_dump);
     $self->_digest_cache($digest_cache);
-    $self->_digest_cache_params(\%cache_params);
+    $self->_digest_cache_params( \%cache_params );
 
     return;
 }
@@ -75,7 +73,7 @@ sub run
     my $self = shift;
 
     my $out;
-    if ($self->_out_to_stdout())
+    if ( $self->_out_to_stdout() )
     {
         open $out, ">&STDOUT";
     }
@@ -89,10 +87,8 @@ sub run
     my $scanner = File::Dir::Dumper::Scanner->new(
         {
             dir => $self->_dir_to_dump(),
-            (
-                (@$digests ? (digests => $digests) : ()),
-            ),
-            digest_cache => $self->_digest_cache,
+            ( ( @$digests ? ( digests => $digests ) : () ), ),
+            digest_cache        => $self->_digest_cache,
             digest_cache_params => $self->_digest_cache_params,
         }
     );
@@ -102,7 +98,7 @@ sub run
         }
     );
 
-    while (defined(my $token = $scanner->fetch()))
+    while ( defined( my $token = $scanner->fetch() ) )
     {
         $writer->put($token);
     }
@@ -113,7 +109,7 @@ sub run
 }
 
 
-1; # End of File::Dir::Dumper
+1;    # End of File::Dir::Dumper
 
 __END__
 
@@ -128,7 +124,7 @@ dumping.
 
 =head1 VERSION
 
-version v0.4.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -138,10 +134,6 @@ version v0.4.0
 
     exit($app->run());
 
-=head1 VERSION
-
-version v0.4.0
-
 =head1 METHODS
 
 =head2 $self->new({ argv => \@ARGV})
@@ -198,37 +190,10 @@ Copyright 2008 Shlomi Fish, all rights reserved.
 
 This program is released under the following license: MIT/X11 Licence.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2008 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/file-dir-dumper/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Dir::Dumper
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -242,15 +207,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/File-Dir-Dumper>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Dir-Dumper>
+L<https://metacpan.org/release/File-Dir-Dumper>
 
 =item *
 
@@ -262,30 +219,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Dir-Dumper>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Dir-Dumper>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Dir-Dumper>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/File-Dir-Dumper>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -296,7 +229,7 @@ L<http://cpants.cpanauthors.org/dist/File-Dir-Dumper>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/F/File-Dir-Dumper>
 
@@ -334,4 +267,25 @@ L<https://github.com/shlomif/perl-File-Dir-Dumper>
 
   git clone https://github.com/shlomif/perl-File-Dir-Dumper
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/file-dir-dumper/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
