@@ -1,5 +1,5 @@
 package File::Dir::Dumper::DigestCache::Dummy;
-$File::Dir::Dumper::DigestCache::Dummy::VERSION = 'v0.4.0';
+$File::Dir::Dumper::DigestCache::Dummy::VERSION = '0.6.0';
 use warnings;
 use strict;
 
@@ -10,7 +10,7 @@ use 5.012;
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     return;
 }
@@ -18,12 +18,12 @@ sub _init
 
 sub get_digests
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     return $args->{calc_cb}->();
 }
 
-1; # End of File::Dir::Dumper
+1;    # End of File::Dir::Dumper
 
 __END__
 
@@ -38,53 +38,22 @@ L<File::Dir::Dumper> .
 
 =head1 VERSION
 
-version v0.4.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
 B<TODO> - see the tests.
 
-=head1 VERSION
-
-version v0.4.0
-
 =head1 METHODS
 
 =head2 $cache->get_digests({calc_cb => sub { return +{...}}})
 
 Returns whatever calc_cb returns. A passthrough.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2008 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/file-dir-dumper/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Dir::Dumper
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -98,15 +67,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/File-Dir-Dumper>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Dir-Dumper>
+L<https://metacpan.org/release/File-Dir-Dumper>
 
 =item *
 
@@ -118,30 +79,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Dir-Dumper>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Dir-Dumper>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Dir-Dumper>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/File-Dir-Dumper>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -152,7 +89,7 @@ L<http://cpants.cpanauthors.org/dist/File-Dir-Dumper>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/F/File-Dir-Dumper>
 
@@ -190,4 +127,25 @@ L<https://github.com/shlomif/perl-File-Dir-Dumper>
 
   git clone https://github.com/shlomif/perl-File-Dir-Dumper
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/file-dir-dumper/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
