@@ -1,5 +1,5 @@
 package File::Dir::Dumper::Stream::JSON::Reader;
-$File::Dir::Dumper::Stream::JSON::Reader::VERSION = 'v0.4.0';
+$File::Dir::Dumper::Stream::JSON::Reader::VERSION = '0.6.0';
 use warnings;
 use strict;
 
@@ -7,11 +7,10 @@ use 5.012;
 
 use parent 'File::Dir::Dumper::Base';
 
-use Carp;
+use Carp ();
 
 use JSON::MaybeXS qw(decode_json);
-use Class::XSAccessor
-    accessors => { _in => 'in' };
+use Class::XSAccessor accessors => { _in => 'in' };
 
 
 sub _init
@@ -19,7 +18,7 @@ sub _init
     my $self = shift;
     my $args = shift;
 
-    $self->_in($args->{input});
+    $self->_in( $args->{input} );
 
     $self->_init_stream();
 
@@ -30,21 +29,21 @@ sub _readline
 {
     my $self = shift;
 
-    return readline($self->_in());
+    return readline( $self->_in() );
 }
 
 sub _eof
 {
     my $self = shift;
 
-    return eof($self->_in());
+    return eof( $self->_in() );
 }
 
 sub _init_stream
 {
     my $self = shift;
 
-    if ($self->_readline() ne "# JSON Stream by Shlomif - Version 0.2.0\n")
+    if ( $self->_readline() ne "# JSON Stream by Shlomif - Version 0.2.0\n" )
     {
         Carp::confess "No header for JSON stream";
     }
@@ -59,16 +58,16 @@ sub fetch
     my $buffer = "";
     my $line;
 
-    if ($self->_eof())
+    if ( $self->_eof() )
     {
         return;
     }
 
-    LINES:
-    while (!$self->_eof())
+LINES:
+    while ( !$self->_eof() )
     {
         $line = $self->_readline();
-        if ($line eq "--/f\n")
+        if ( $line eq "--/f\n" )
         {
             return decode_json($buffer);
         }
@@ -81,7 +80,7 @@ sub fetch
 }
 
 
-1; # End of File::Dir::Dumper
+1;    # End of File::Dir::Dumper
 
 __END__
 
@@ -95,7 +94,7 @@ File::Dir::Dumper::Stream::JSON::Reader - reader for stream of JSON objects.
 
 =head1 VERSION
 
-version v0.4.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -112,10 +111,6 @@ version v0.4.0
         # Do something with $token.
     }
 
-=head1 VERSION
-
-version v0.4.0
-
 =head1 METHODS
 
 =head2 $self->new({ input => $in_filehandle})
@@ -172,37 +167,10 @@ Copyright 2008 Shlomi Fish, all rights reserved.
 
 This program is released under the following license: MIT/X11 Licence.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2008 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/file-dir-dumper/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Dir::Dumper
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -216,15 +184,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/File-Dir-Dumper>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Dir-Dumper>
+L<https://metacpan.org/release/File-Dir-Dumper>
 
 =item *
 
@@ -236,30 +196,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Dir-Dumper>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Dir-Dumper>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Dir-Dumper>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/File-Dir-Dumper>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -270,7 +206,7 @@ L<http://cpants.cpanauthors.org/dist/File-Dir-Dumper>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/F/File-Dir-Dumper>
 
@@ -308,4 +244,25 @@ L<https://github.com/shlomif/perl-File-Dir-Dumper>
 
   git clone https://github.com/shlomif/perl-File-Dir-Dumper
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/file-dir-dumper/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
